@@ -6,15 +6,15 @@
 
 #pragma once
 
+#include "change.h"
 #include "object.h"
 #include "types.h"
-#include "change.h"
 
+#include <QImage>
 #include <QString>
 #include <QStringList>
 #include <QUrl>
 #include <QVariantMap>
-#include <QImage>
 
 #include <QDateTime>
 
@@ -33,28 +33,31 @@ namespace Drive
  * @author Andrius da Costa Ribas <andriusmao@gmail.com>
  * @author Daniel Vrátil <dvratil@redhat.com>
  */
-class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
+class KGAPIDRIVE_EXPORT File : public KGAPI2::Object
 {
-  private:
+private:
     class Private;
 
-  public:
+public:
     /**
      * @brief DriveFile::Labels holds the structure used for labels property.
      */
     class Labels
     {
-      public:
+    public:
         explicit Labels();
         explicit Labels(const Labels &other);
         virtual ~Labels();
         bool operator==(const Labels &other) const;
-        bool operator!=(const Labels &other) const { return !operator==(other); }
+        bool operator!=(const Labels &other) const
+        {
+            return !operator==(other);
+        }
 
         /**
          * @brief Returns whether this file is starred by the user.
          */
-        bool starred() const;
+        [[nodiscard]] bool starred() const;
 
         /**
          * @brief Sets whether this file is starred by the user.
@@ -107,7 +110,7 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
         /**
          * @brief Returns whether this file has been viewed by this user.
          */
-        bool viewed() const;
+        [[nodiscard]] bool viewed() const;
 
         /**
          * @brief Sets whether this file has been viewed by this user.
@@ -116,7 +119,7 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
          */
         void setViewed(bool viewed);
 
-      private:
+    private:
         class Private;
         Private *const d;
         friend class Private;
@@ -131,16 +134,19 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
      */
     class IndexableText
     {
-      public:
+    public:
         explicit IndexableText(const IndexableText &other);
         virtual ~IndexableText();
         bool operator==(const IndexableText &other) const;
-        bool operator!=(const IndexableText &other) const { return !operator==(other); }
+        bool operator!=(const IndexableText &other) const
+        {
+            return !operator==(other);
+        }
 
         /**
          * @brief Returns the text to be indexed for this file.
          */
-        QString text() const;
+        [[nodiscard]] QString text() const;
 
         /**
          * @brief Sets the text to be indexed for this file.
@@ -149,7 +155,7 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
          */
         void setText(const QString &text);
 
-      private:
+    private:
         explicit IndexableText();
 
         class Private;
@@ -166,35 +172,38 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
      */
     class ImageMediaMetadata
     {
-      public:
+    public:
         /**
          * @brief DriveFile::ImageMediaMetadata::Location holds the structure used
          *        for imageMediaMetadata.location property.
          */
         class Location
         {
-          public:
+        public:
             explicit Location(const Location &other);
             virtual ~Location();
             bool operator==(const Location &other) const;
-            bool operator!=(const Location &other) const { return !operator==(other); }
+            bool operator!=(const Location &other) const
+            {
+                return !operator==(other);
+            }
 
             /**
              * @brief Returns the latitude stored in the image.
              */
-            qreal latitude() const;
+            [[nodiscard]] qreal latitude() const;
 
             /**
              * @brief Returns the longitude stored in the image.
              */
-            qreal longitude() const;
+            [[nodiscard]] qreal longitude() const;
 
             /**
              * @brief Returns the altitude stored in the image.
              */
-            qreal altitude() const;
+            [[nodiscard]] qreal altitude() const;
 
-          private:
+        private:
             explicit Location();
 
             class Private;
@@ -208,63 +217,66 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
         explicit ImageMediaMetadata(const ImageMediaMetadata &other);
         virtual ~ImageMediaMetadata();
         bool operator==(const ImageMediaMetadata &other) const;
-        bool operator!=(const ImageMediaMetadata &other) const { return !operator==(other); }
+        bool operator!=(const ImageMediaMetadata &other) const
+        {
+            return !operator==(other);
+        }
 
         /**
          * @brief Returns the width of the image in pixels.
          */
-        int width() const;
+        [[nodiscard]] int width() const;
 
         /**
          * @brief Returns the height of the image in pixels.
          */
-        int height() const;
+        [[nodiscard]] int height() const;
 
         /**
          * @brief Returns the rotation in clockwise degrees from the image's original orientation.
          */
-        int rotation() const;
+        [[nodiscard]] int rotation() const;
 
         /**
          * @brief Returns the geographic location information stored in the image.
          */
-        LocationPtr location() const;
+        [[nodiscard]] LocationPtr location() const;
 
-        QString date() const;
+        [[nodiscard]] QString date() const;
 
-        QString cameraMake() const;
+        [[nodiscard]] QString cameraMake() const;
 
-        QString cameraModel() const;
+        [[nodiscard]] QString cameraModel() const;
 
-        float exposureTime() const;
+        [[nodiscard]] float exposureTime() const;
 
-        float aperture()  const;
+        [[nodiscard]] float aperture() const;
 
-        bool flashUsed() const;
+        [[nodiscard]] bool flashUsed() const;
 
-        float focalLength() const;
+        [[nodiscard]] float focalLength() const;
 
-        int isoSpeed() const;
+        [[nodiscard]] int isoSpeed() const;
 
-        QString meteringMode() const;
+        [[nodiscard]] QString meteringMode() const;
 
-        QString sensor() const;
+        [[nodiscard]] QString sensor() const;
 
-        QString exposureMode() const;
+        [[nodiscard]] QString exposureMode() const;
 
-        QString colorSpace() const;
+        [[nodiscard]] QString colorSpace() const;
 
-        QString whiteBalance() const;
+        [[nodiscard]] QString whiteBalance() const;
 
-        float exposureBias() const;
+        [[nodiscard]] float exposureBias() const;
 
-        float maxApertureValue() const;
+        [[nodiscard]] float maxApertureValue() const;
 
-        int subjectDistance() const;
+        [[nodiscard]] int subjectDistance() const;
 
-        QString lens() const;
+        [[nodiscard]] QString lens() const;
 
-      private:
+    private:
         explicit ImageMediaMetadata(const QVariantMap &jsonMap);
 
         class Private;
@@ -277,21 +289,24 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
 
     class Thumbnail
     {
-      public:
+    public:
         explicit Thumbnail(const Thumbnail &other);
         virtual ~Thumbnail();
         bool operator==(const Thumbnail &other) const;
-        bool operator!=(const Thumbnail &other) const { return !operator==(other); }
+        bool operator!=(const Thumbnail &other) const
+        {
+            return !operator==(other);
+        }
 
-        QImage image() const;
+        [[nodiscard]] QImage image() const;
 
-        QString mimeType() const;
+        [[nodiscard]] QString mimeType() const;
 
-      private:
+    private:
         explicit Thumbnail(const QVariantMap &jsonMap);
 
         class Private;
-        Private * const d;
+        Private *const d;
         friend class Private;
         friend class File::Private;
     };
@@ -303,8 +318,8 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
      * @since 5.3.1
      */
     enum SerializationOption {
-        NoOptions = 0,             ///< No option set.
-        ExcludeCreationDate = 1    ///< Exclude 'createdDate' entry. This is necessary when renaming URLs.
+        NoOptions = 0, ///< No option set.
+        ExcludeCreationDate = 1 ///< Exclude 'createdDate' entry. This is necessary when renaming URLs.
     };
     Q_DECLARE_FLAGS(SerializationOptions, SerializationOption)
 
@@ -312,7 +327,10 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
     explicit File(const File &other);
     ~File() override;
     bool operator==(const File &other) const;
-    bool operator!=(const File &other) const { return !operator==(other); }
+    bool operator!=(const File &other) const
+    {
+        return !operator==(other);
+    }
 
     /**
      * @brief Returns mimetype of folders
@@ -322,19 +340,19 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
     /**
      * @brief Returns the id of the file.
      */
-    QString id() const;
+    [[nodiscard]] QString id() const;
 
     /**
      * @brief Returns a link back to this file.
      */
-    QUrl selfLink() const;
+    [[nodiscard]] QUrl selfLink() const;
 
     /**
      * @brief Returns the title of this file.
      *
      * Used to identify file or folder name.
      */
-    QString title() const;
+    [[nodiscard]] QString title() const;
 
     /**
      * @brief Sets the title of this file.
@@ -348,7 +366,7 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
     /**
      * @brief Returns the MIME type of the file.
      */
-    QString mimeType() const;
+    [[nodiscard]] QString mimeType() const;
 
     /**
      * @brief Sets the MIME type of the file.
@@ -360,7 +378,7 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
     /**
      * @brief Returns a short description of the file.
      */
-    QString description() const;
+    [[nodiscard]] QString description() const;
 
     /**
      * @brief Sets a short description of the file.
@@ -384,14 +402,14 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
     /**
      * @brief Returns the create time for this file.
      */
-    QDateTime createdDate() const;
+    [[nodiscard]] QDateTime createdDate() const;
 
     /**
      * @brief Returns the last time this file was modified by anyone.
      *
      * This is only mutable on update when the setModifiedDate parameter is set.
      */
-    QDateTime modifiedDate() const;
+    [[nodiscard]] QDateTime modifiedDate() const;
 
     /**
      * @brief Sets the last time this file was modified by anyone.
@@ -406,21 +424,21 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
      * @brief Returns the last time this file was modified by the currently
      *        authenticated user.
      */
-    QDateTime modifiedByMeDate() const;
+    [[nodiscard]] QDateTime modifiedByMeDate() const;
 
     /**
      * @brief Returns a short lived download URL for the file.
      *
      * This is only populated for files with content stored in Drive.
      */
-    QUrl downloadUrl() const;
+    [[nodiscard]] QUrl downloadUrl() const;
 
     /**
      * @brief Returns the indexable text attributes for the file.
      *
      * This property can only be written, and is not returned by files.get
      */
-    File::IndexableTextPtr& indexableText();
+    File::IndexableTextPtr &indexableText();
 
     /**
      * @brief Returns the permissions for the authenticated user on this file.
@@ -433,42 +451,42 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
      * This field is read only. To set the extension, include it on title when creating the file.
      * This is populated only for files with content stored in Drive.
      */
-    QString fileExtension() const;
+    [[nodiscard]] QString fileExtension() const;
 
     /**
      * @brief Returns an MD5 checksum for the content of this file.
      *
      * This is populated only for files with content stored in Drive.
      */
-    QString md5Checksum() const;
+    [[nodiscard]] QString md5Checksum() const;
 
     /**
      * @brief Returns the size of the file in bytes.
      *
      * This is populated only for files with content stored in Drive.
      */
-    qlonglong fileSize() const;
+    [[nodiscard]] qlonglong fileSize() const;
 
     /**
      * @brief Returns a link for opening the file in using a relevant
      *        Google editor or viewer.
      */
-    QUrl alternateLink() const;
+    [[nodiscard]] QUrl alternateLink() const;
 
     /**
      * @brief Returns a link for embedding the file.
      */
-    QUrl embedLink() const;
+    [[nodiscard]] QUrl embedLink() const;
 
     /**
      * @brief Returns the version of the file;
      */
-    qlonglong version() const;
+    [[nodiscard]] qlonglong version() const;
 
     /**
      * @brief Returns the time at which this file was shared with the user.
      */
-    QDateTime sharedWithMeDate() const;
+    [[nodiscard]] QDateTime sharedWithMeDate() const;
 
     /**
      * @brief Returns the collection of parent folders which contain this file.
@@ -495,7 +513,7 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
      *
      * This is a map from the export format to URL.
      */
-    QMap < QString /* format */, QUrl /* url */ > exportLinks() const;
+    QMap<QString /* format */, QUrl /* url */> exportLinks() const;
 
     /**
      * @brief Returns the original filename if the file was uploaded manually,
@@ -504,44 +522,44 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
      * Note that renames of the title will not change the original filename.
      * This will only be populated on files with content stored in Drive.
      */
-    QString originalFileName() const;
+    [[nodiscard]] QString originalFileName() const;
 
     /**
      * @brief Returns the number of quota bytes used by this file.
      */
-    qlonglong quotaBytesUsed() const;
+    [[nodiscard]] qlonglong quotaBytesUsed() const;
 
     /**
      * @brief Return the name(s) of the owner(s) of this file.
      */
-    QStringList ownerNames() const;
+    [[nodiscard]] QStringList ownerNames() const;
 
     /**
      * @brief Returns the name of the last user to modify this file.
      *
      * This will only be populated if a user has edited this file.
      */
-    QString lastModifyingUserName() const;
+    [[nodiscard]] QString lastModifyingUserName() const;
 
     /**
      * @brief Returns whether the file can be edited by the current user.
      */
-    bool editable() const;
+    [[nodiscard]] bool editable() const;
 
     /**
      * @brief Returns whether writers can share the document with other users.
      */
-    bool writersCanShare() const;
+    [[nodiscard]] bool writersCanShare() const;
 
     /**
      * @brief Returns a link to the file's thumbnail.
      */
-    QUrl thumbnailLink() const;
+    [[nodiscard]] QUrl thumbnailLink() const;
 
     /**
      * @brief Returns the last time this file was viewed by the user.
      */
-    QDateTime lastViewedByMeDate() const;
+    [[nodiscard]] QDateTime lastViewedByMeDate() const;
 
     /**
      * @brief Sets the last time this file was viewed by the user.
@@ -557,7 +575,7 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
      * In cases where the content is shared publicly, the content can be
      * downloaded without any credentials.
      */
-    QUrl webContentLink() const;
+    [[nodiscard]] QUrl webContentLink() const;
 
     /**
      * @brief Returns whether this file has been explicitly trashed, as opposed
@@ -565,7 +583,7 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
      *
      * This will only be populated if the file is trashed.
      */
-    bool explicitlyTrashed() const;
+    [[nodiscard]] bool explicitlyTrashed() const;
 
     /**
      * @brief Returns metadata about image media.
@@ -580,17 +598,17 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
      */
     ThumbnailPtr thumbnail() const;
 
-    QUrl webViewLink() const;
+    [[nodiscard]] QUrl webViewLink() const;
 
-    QUrl iconLink() const;
+    [[nodiscard]] QUrl iconLink() const;
 
-    bool shared() const;
+    [[nodiscard]] bool shared() const;
 
-    UsersList owners() const;
+    [[nodiscard]] UsersList owners() const;
 
-    UserPtr lastModifyingUser() const;
+    [[nodiscard]] UserPtr lastModifyingUser() const;
 
-    bool isFolder() const;
+    [[nodiscard]] bool isFolder() const;
 
     struct Fields {
         static const QString Items;
@@ -647,13 +665,13 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
     };
 
     static FilePtr fromJSON(const QByteArray &jsonData);
-    static FilesList fromJSONFeed(const  QByteArray &jsonData, FeedData &feedData);
+    static FilesList fromJSONFeed(const QByteArray &jsonData, FeedData &feedData);
     static QByteArray toJSON(const FilePtr &file, SerializationOptions options = NoOptions);
 
     static FilePtr fromJSON(const QVariantMap &jsonData);
 
 private:
-    Private * const d;
+    Private *const d;
     friend class Private;
     friend class Change::Private;
     friend class ParentReference;
@@ -665,4 +683,3 @@ private:
 } /* namespace KGAPI2 */
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KGAPI2::Drive::File::SerializationOptions)
-
