@@ -7,13 +7,13 @@
  */
 
 #include "filemodifyjob.h"
-#include "file.h"
 #include "debug.h"
 #include "driveservice.h"
+#include "file.h"
 #include "utils.h"
 
-#include <QNetworkRequest>
 #include <QNetworkAccessManager>
+#include <QNetworkRequest>
 #include <QUrlQuery>
 
 using namespace KGAPI2;
@@ -21,10 +21,10 @@ using namespace KGAPI2::Drive;
 
 class Q_DECL_HIDDEN FileModifyJob::Private
 {
-  public:
+public:
     Private();
 
-    QMap < QString /* filepath */, QString /* fileId */ > files;
+    QMap<QString /* filepath */, QString /* fileId */> files;
 
     bool createNewRevision = true;
     bool changeModifiedDate = false;
@@ -35,51 +35,39 @@ FileModifyJob::Private::Private()
 {
 }
 
-FileModifyJob::FileModifyJob(const FilePtr &metadata,
-                             const AccountPtr &account,
-                             QObject *parent):
-    FileAbstractUploadJob(metadata, account, parent),
-    d(new Private)
+FileModifyJob::FileModifyJob(const FilePtr &metadata, const AccountPtr &account, QObject *parent)
+    : FileAbstractUploadJob(metadata, account, parent)
+    , d(new Private)
 {
     d->files.insert(QStringLiteral("?=0"), metadata->id());
     setSerializationOptions(File::ExcludeCreationDate);
 }
 
-FileModifyJob::FileModifyJob(const QString &filePath,
-                             const QString &fileId,
-                             const AccountPtr &account,
-                             QObject *parent):
-    FileAbstractUploadJob(filePath, account, parent),
-    d(new Private)
+FileModifyJob::FileModifyJob(const QString &filePath, const QString &fileId, const AccountPtr &account, QObject *parent)
+    : FileAbstractUploadJob(filePath, account, parent)
+    , d(new Private)
 {
     d->files.insert(filePath, fileId);
 }
 
-FileModifyJob::FileModifyJob(const QString &filePath,
-                             const FilePtr &metaData,
-                             const AccountPtr &account,
-                             QObject *parent):
-    FileAbstractUploadJob(filePath, metaData, account, parent),
-    d(new Private)
+FileModifyJob::FileModifyJob(const QString &filePath, const FilePtr &metaData, const AccountPtr &account, QObject *parent)
+    : FileAbstractUploadJob(filePath, metaData, account, parent)
+    , d(new Private)
 {
     d->files.insert(filePath, metaData->id());
     setSerializationOptions(File::ExcludeCreationDate);
 }
 
-FileModifyJob::FileModifyJob(const QMap< QString, QString > &files,
-                             const AccountPtr &account,
-                             QObject *parent):
-    FileAbstractUploadJob(files.keys(), account, parent),
-    d(new Private)
+FileModifyJob::FileModifyJob(const QMap<QString, QString> &files, const AccountPtr &account, QObject *parent)
+    : FileAbstractUploadJob(files.keys(), account, parent)
+    , d(new Private)
 {
     d->files = files;
 }
 
-FileModifyJob::FileModifyJob(const QMap< QString, FilePtr > &files,
-                             const AccountPtr &account,
-                             QObject *parent):
-    FileAbstractUploadJob(files, account, parent),
-    d(new Private)
+FileModifyJob::FileModifyJob(const QMap<QString, FilePtr> &files, const AccountPtr &account, QObject *parent)
+    : FileAbstractUploadJob(files, account, parent)
+    , d(new Private)
 {
     QMap<QString, FilePtr>::ConstIterator iter = files.constBegin();
     QMap<QString, FilePtr>::ConstIterator iterEnd = files.constEnd();
@@ -139,8 +127,7 @@ void FileModifyJob::setUpdateViewedDate(bool updateViewedDate)
     d->updateViewedDate = updateViewedDate;
 }
 
-QUrl FileModifyJob::createUrl(const QString &filePath,
-                              const FilePtr &metaData)
+QUrl FileModifyJob::createUrl(const QString &filePath, const FilePtr &metaData)
 {
     QUrl url;
 
@@ -161,12 +148,9 @@ QUrl FileModifyJob::createUrl(const QString &filePath,
     return url;
 }
 
-QNetworkReply *FileModifyJob::dispatch(QNetworkAccessManager *accessManager,
-                                       const QNetworkRequest &request,
-                                       const QByteArray &data)
+QNetworkReply *FileModifyJob::dispatch(QNetworkAccessManager *accessManager, const QNetworkRequest &request, const QByteArray &data)
 {
     return accessManager->put(request, data);
 }
 
-
-
+#include "moc_filemodifyjob.cpp"
