@@ -7,46 +7,45 @@
  */
 
 #include "taskcreatejob.h"
-#include "tasksservice.h"
 #include "account.h"
 #include "debug.h"
-#include "utils.h"
-#include "task.h"
 #include "private/queuehelper_p.h"
+#include "task.h"
+#include "tasksservice.h"
+#include "utils.h"
 
-#include <QNetworkRequest>
 #include <QNetworkReply>
+#include <QNetworkRequest>
 #include <QUrlQuery>
 
 using namespace KGAPI2;
 
-namespace {
-    static const auto ParentParam = QStringLiteral("parent");
-    static const auto PreviousParam = QStringLiteral("previous");
+namespace
+{
+static const auto ParentParam = QStringLiteral("parent");
+static const auto PreviousParam = QStringLiteral("previous");
 }
 
 class Q_DECL_HIDDEN TaskCreateJob::Private
 {
-  public:
+public:
     QueueHelper<TaskPtr> tasks;
     QString taskListId;
     QString parentId;
     QString previousId;
 };
 
-TaskCreateJob::TaskCreateJob(const TaskPtr& task, const QString& taskListId,
-                             const AccountPtr& account, QObject* parent):
-    CreateJob(account, parent),
-    d(new Private)
+TaskCreateJob::TaskCreateJob(const TaskPtr &task, const QString &taskListId, const AccountPtr &account, QObject *parent)
+    : CreateJob(account, parent)
+    , d(new Private)
 {
     d->tasks << task;
     d->taskListId = taskListId;
 }
 
-TaskCreateJob::TaskCreateJob(const TasksList& tasks, const QString& taskListId,
-                             const AccountPtr& account, QObject* parent):
-    CreateJob(account, parent),
-    d(new Private)
+TaskCreateJob::TaskCreateJob(const TasksList &tasks, const QString &taskListId, const AccountPtr &account, QObject *parent)
+    : CreateJob(account, parent)
+    , d(new Private)
 {
     d->tasks = tasks;
     d->taskListId = taskListId;
@@ -86,7 +85,7 @@ void TaskCreateJob::setPrevious(const QString &previousId)
 
 void TaskCreateJob::start()
 {
-   if (d->tasks.atEnd()) {
+    if (d->tasks.atEnd()) {
         emitFinished();
         return;
     }
@@ -109,7 +108,7 @@ void TaskCreateJob::start()
     enqueueRequest(request, rawData, QStringLiteral("application/json"));
 }
 
-ObjectsList TaskCreateJob::handleReplyWithItems(const QNetworkReply *reply, const QByteArray& rawData)
+ObjectsList TaskCreateJob::handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData)
 {
     const QString contentType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     ContentType ct = Utils::stringToContentType(contentType);
@@ -130,4 +129,4 @@ ObjectsList TaskCreateJob::handleReplyWithItems(const QNetworkReply *reply, cons
     return items;
 }
 
-
+#include "moc_taskcreatejob.cpp"
